@@ -448,7 +448,7 @@ qemuAgentUnregister(qemuAgent *agent)
 {
     if (agent->watch) {
         g_source_destroy(agent->watch);
-        vir_g_source_unref(agent->watch, agent->context);
+        g_source_unref(agent->watch);
         agent->watch = NULL;
     }
 }
